[geos-commits] [SCM] GEOS branch master updated. 56d361d0ea9cc692cdc1120e82119997aa12c4fc

git at osgeo.org git at osgeo.org
Wed Dec 9 09:57:57 PST 2020


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GEOS".

The branch, master has been updated
       via  56d361d0ea9cc692cdc1120e82119997aa12c4fc (commit)
      from  f8f42a730f709a144d6f3193e9aa319775f8d3dc (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 56d361d0ea9cc692cdc1120e82119997aa12c4fc
Author: Paul Ramsey <pramsey at cleverelephant.ca>
Date:   Wed Dec 9 09:57:48 2020 -0800

    Initialize useAreaReducer. Closes #1067

diff --git a/src/precision/GeometryPrecisionReducer.cpp b/src/precision/GeometryPrecisionReducer.cpp
index 86003ad..a38053d 100644
--- a/src/precision/GeometryPrecisionReducer.cpp
+++ b/src/precision/GeometryPrecisionReducer.cpp
@@ -41,17 +41,6 @@ namespace precision { // geos.precision
 
 
 /* public */
-GeometryPrecisionReducer::GeometryPrecisionReducer(const GeometryFactory& changeFactory)
-    :
-    newFactory(&changeFactory),
-    targetPM(*(changeFactory.getPrecisionModel())),
-    removeCollapsed(true),
-    useAreaReducer(false),
-    isPointwise(false)
-{}
-
-
-/* public */
 std::unique_ptr<Geometry>
 GeometryPrecisionReducer::reduce(const Geometry& geom)
 {

-----------------------------------------------------------------------

Summary of changes:
 include/geos/precision/GeometryPrecisionReducer.h | 12 ++++++++++--
 src/precision/GeometryPrecisionReducer.cpp        | 11 -----------
 2 files changed, 10 insertions(+), 13 deletions(-)


hooks/post-receive
diff --git a/include/geos/precision/GeometryPrecisionReducer.h b/include/geos/precision/GeometryPrecisionReducer.h
index 51c659d..cf8a245 100644
--- a/include/geos/precision/GeometryPrecisionReducer.h
+++ b/include/geos/precision/GeometryPrecisionReducer.h
@@ -128,6 +128,7 @@ public:
         , targetPM(pm)
         , removeCollapsed(true)
         , changePrecisionModel(false)
+        , useAreaReducer(false)
         , isPointwise(false)
     {}
 
@@ -136,12 +137,19 @@ public:
      * Create a reducer that will change the precision model of the
      * new reduced Geometry
      *
      * @param gf the factory for the created Geometry.
      *           Its PrecisionModel will be used for the reduction.
      *           NOTE: ownership left to caller must be kept alive for
      *           the whole lifetime of the returned Geometry.
      */
-    GeometryPrecisionReducer(const geom::GeometryFactory& gf);
+    GeometryPrecisionReducer(const geom::GeometryFactory& changeFactory)
+        : newFactory(&changeFactory)
+        , targetPM(*(changeFactory.getPrecisionModel()))
+        , removeCollapsed(true)
+        , changePrecisionModel(false)
+        , useAreaReducer(false)
+        , isPointwise(false)
+    {}
 
     /**
      * Sets whether the reduction will result in collapsed components
@@ -136,12 +137,19 @@ public:
      * new reduced Geometry
      *
-     * @param gf the factory for the created Geometry.
+     * @param changeFactory the factory for the created Geometry.
      *           Its PrecisionModel will be used for the reduction.
      *           NOTE: ownership left to caller must be kept alive for
-- 
GEOS


More information about the geos-commits mailing list